@@ -306,9 +306,6 @@ func (p *parser) parseWithArgExpr() (*withArgExpr, error) {
 		return nil, fmt.Errorf(`withArgExpr: unexpected token %q; want "ident"`, p.lex.Token)
 	}
 	wa.Name = unescapeIdent(p.lex.Token)
-	if isAggrFunc(wa.Name) || IsRollupFunc(wa.Name) || IsTransformFunc(wa.Name) || isWith(wa.Name) {
-		return nil, fmt.Errorf(`withArgExpr: cannot use reserved name %q`, wa.Name)
-	}
 	if err := p.lex.Next(); err != nil {
 		return nil, err
 	}
@@ -682,17 +679,21 @@ func expandWithExpr(was []*withArgExpr, e Expr) (Expr, error) {
 			return nil, err
 		}
 		wa := getWithArgExpr(was, t.Name)
-		if wa == nil {
-			fe := *t
-			fe.Args = args
-			return &fe, nil
+		if wa != nil {
+			return expandWithExprExt(was, wa, args)
 		}
-		return expandWithExprExt(was, wa, args)
+		fe := *t
+		fe.Args = args
+		return &fe, nil
 	case *AggrFuncExpr:
 		args, err := expandWithArgs(was, t.Args)
 		if err != nil {
 			return nil, err
 		}
+		wa := getWithArgExpr(was, t.Name)
+		if wa != nil {
+			return expandWithExprExt(was, wa, args)
+		}
 		modifierArgs, err := expandModifierArgs(was, t.Modifier.Args)
 		if err != nil {
 			return nil, err
