@@ -28,6 +28,7 @@ var transformFuncs = map[string]bool{
 	"day_of_week":          true,
 	"days_in_month":        true,
 	"deg":                  true,
+	"drop_common_labels":   true,
 	"end":                  true,
 	"exp":                  true,
 	"floor":                true,
@@ -56,6 +57,7 @@ var transformFuncs = map[string]bool{
 	"label_transform":      true,
 	"label_uppercase":      true,
 	"label_value":          true,
+	"limit_offset":         true,
 	"ln":                   true,
 	"log2":                 true,
 	"log10":                true,
